@@ -17,16 +17,14 @@ APIs for interacting with Fulcio.
 """
 
 
-from ._client import (
-    FulcioCertificateSigningRequest,
+from .client import (
+    DetachedFulcioSCT,
     FulcioCertificateSigningResponse,
     FulcioClient,
-    FulcioSignedCertificateTimestamp,
 )
 
 __all__ = [
-    "FulcioCertificateSigningRequest",
+    "DetachedFulcioSCT",
     "FulcioCertificateSigningResponse",
     "FulcioClient",
-    "FulcioSignedCertificateTimestamp",
 ]
